@@ -1,12 +1,10 @@
-use anyhow;
 use binread::{
     io::{Read, Seek},
     BinRead, BinReaderExt,
 };
 
-use crate::common::{Color4, TexCoord, Vector3};
-
 use super::NiString;
+use crate::common::{Color4, TexCoord, Vector3};
 
 #[derive(Debug, PartialEq, BinRead)]
 pub struct NiGeometryData {
@@ -40,13 +38,20 @@ pub struct NiGeometryData {
     #[br(if(has_vertex_colors), count = num_vertices)]
     pub vertex_colors: Option<Vec<Color4>>,
 
-    #[br(if(num_uv_sets & 63 > 0), count = num_vertices)]
-    pub uv_sets: Option<Vec<TexCoord>>,
+    #[br(count = num_uv_sets & 63, args(num_vertices))]
+    pub uv_sets: Vec<UvSet>,
 
     pub consistency_flags: u16,
     pub additional_data_ref: i32,
 }
 
+#[derive(Debug, PartialEq, BinRead)]
+#[br(import(num_vertices: u16))]
+pub struct UvSet {
+    #[br(count = num_vertices)]
+    pub uvs: Vec<TexCoord>,
+}
+
 impl NiGeometryData {
     pub fn parse<R: Read + Seek>(reader: &mut R) -> anyhow::Result<Self> {
         Ok(reader.read_le()?)
