@@ -1,17 +1,17 @@
-use super::ni_object_net::NiObjectNET;
-use anyhow;
 use binread::{
     io::{Read, Seek},
     BinRead, BinReaderExt,
 };
 
+use super::NiObjectNET;
+use crate::common::Color3;
 #[derive(Debug, PartialEq, BinRead)]
 pub struct NiMaterialProperty {
     pub base: NiObjectNET,
-    pub color_ambient: (f32, f32, f32),
-    pub color_diffuse: (f32, f32, f32),
-    pub color_specular: (f32, f32, f32),
-    pub color_emissive: (f32, f32, f32),
+    pub color_ambient: Color3,
+    pub color_diffuse: Color3,
+    pub color_specular: Color3,
+    pub color_emissive: Color3,
     pub glossiness: f32,
     pub alpha: f32,
 }
